@@ -14,14 +14,25 @@ class Gitalist::Git::Object::Tree
 
 __END__
 
-
 =head1 NAME
 
 Gitalist::Git::Object::Tree
 
+=head1 SYNOPSIS
+
+    my $tree = Project->get_object($tree_sha1);
+
 =head1 DESCRIPTION
 
-Gitalist::Git::Object::Tree.
+Represents a tree object in a git repository.
+Subclass of C<Gitalist::Git::Object>.
+
+
+=head1 ATTRIBUTES
+
+
+=head1 METHODS
+
 
 =head1 AUTHORS
 
